@@ -1,10 +1,12 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-# @Author: oesteban
-# @Date:   2017-06-08 17:07:37
 
 from .parameters import ModelParameterGrid
 from .cv_nested import ModelAndGridSearchCV
 from ._split import RobustLeavePGroupsOut
+
+__all__ = [
+    "ModelParameterGrid",
+    "ModelAndGridSearchCV",
+    "RobustLeavePGroupsOut",
+]
