@@ -1,8 +1,10 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-""" Module utils.misc contains utilities """
-from __future__ import print_function, division, absolute_import, unicode_literals
+"""Module utils.misc contains utilities."""
 from .misc import reorder_csv
 from .bids import collect_bids_data
+
+__all__ = [
+    "reorder_csv",
+    "collect_bids_data",
+]
