@@ -23,57 +23,45 @@ The functional workflow follows the following steps:
 This workflow is orchestrated by :py:func:`fmri_qc_workflow`.
 
 """
-from __future__ import print_function, division, absolute_import, unicode_literals
-import os.path as op
-from pathlib import Path
-
+from .. import config
 from nipype.pipeline import engine as pe
 from nipype.algorithms import confounds as nac
 from nipype.interfaces import io as nio
 from nipype.interfaces import utility as niu
 from nipype.interfaces import afni, ants, fsl
 
-from niworkflows.interfaces import segmentation as nws
-from niworkflows.interfaces import registration as nwr
-from niworkflows.interfaces import utils as niutils
-from niworkflows.interfaces.plotting import FMRISummary
-
 from .utils import get_fwhmx
-from .. import DEFAULTS, logging
-from ..interfaces import ReadSidecarJSON, FunctionalQC, Spikes, IQMFileSink
+from ..interfaces import FunctionalQC, Spikes, IQMFileSink
+from ..interfaces.reports import AddProvenance
 
 
-DEFAULT_FD_RADIUS = 50.
-WFLOGGER = logging.getLogger('mriqc.workflow')
-
-
-def fmri_qc_workflow(dataset, settings, name='funcMRIQC'):
+def fmri_qc_workflow(name='funcMRIQC'):
     """
     The fMRI qc workflow
 
     .. workflow::
 
-      import os.path as op
-      from mriqc.workflows.functional import fmri_qc_workflow
-      datadir = op.abspath('data')
-      wf = fmri_qc_workflow([op.join(datadir, 'sub-001/func/sub-001_task-rest_bold.nii.gz')],
-                            settings={'bids_dir': datadir,
-                                      'output_dir': op.abspath('out'),
-                                      'no_sub': True})
+        import os.path as op
+        from mriqc.workflows.functional import fmri_qc_workflow
+        from mriqc.testing import mock_config
+        with mock_config():
+            wf = fmri_qc_workflow()
 
 
     """
+    from niworkflows.interfaces.utils import SanitizeImage
 
     workflow = pe.Workflow(name=name)
 
-    biggest_file_gb = settings.get("biggest_file_size_gb", 1)
+    mem_gb = config.workflow.biggest_file_gb
+
+    dataset = config.workflow.inputs.get("bold", [])
+    config.loggers.workflow.info(f"""\
+Building functional MRIQC workflow for files: {', '.join(dataset)}.""")
 
     # Define workflow, inputs and outputs
     # 0. Get data, put it in RAS orientation
     inputnode = pe.Node(niu.IdentityInterface(fields=['in_file']), name='inputnode')
-    WFLOGGER.info('Building fMRI QC workflow, datasets list: %s',
-                  [str(Path(d).relative_to(settings['bids_dir']))
-                   for d in sorted(dataset)])
     inputnode.iterables = [('in_file', dataset)]
 
     outputnode = pe.Node(niu.IdentityInterface(
@@ -83,41 +71,36 @@ def fmri_qc_workflow(dataset, settings, name='funcMRIQC'):
     non_steady_state_detector = pe.Node(nac.NonSteadyStateDetector(),
                                         name="non_steady_state_detector")
 
-    sanitize = pe.Node(niutils.SanitizeImage(), name="sanitize",
-                       mem_gb=biggest_file_gb * 4.0)
-    sanitize.inputs.max_32bit = settings.get("float32", DEFAULTS['float32'])
+    sanitize = pe.Node(SanitizeImage(), name="sanitize",
+                       mem_gb=mem_gb * 4.0)
+    sanitize.inputs.max_32bit = config.execution.float32
 
     # Workflow --------------------------------------------------------
 
     # 1. HMC: head motion correct
-    if settings.get('hmc_fsl', False):
-        hmcwf = hmc_mcflirt(settings)
+    if config.workflow.hmc_fsl:
+        hmcwf = hmc_mcflirt()
     else:
-        hmcwf = hmc_afni(settings,
-                         st_correct=settings.get('correct_slice_timing', False),
-                         despike=settings.get('despike', False),
-                         deoblique=settings.get('deoblique', False),
-                         start_idx=settings.get('start_idx', None),
-                         stop_idx=settings.get('stop_idx', None))
+        hmcwf = hmc_afni()
 
     # Set HMC settings
-    hmcwf.inputs.inputnode.fd_radius = settings.get('fd_radius', DEFAULT_FD_RADIUS)
+    hmcwf.inputs.inputnode.fd_radius = config.workflow.fd_radius
 
     mean = pe.Node(afni.TStat(                   # 2. Compute mean fmri
         options='-mean', outputtype='NIFTI_GZ'), name='mean',
-        mem_gb=biggest_file_gb * 1.5)
+        mem_gb=mem_gb * 1.5)
     skullstrip_epi = fmri_bmsk_workflow(use_bet=True)
 
     # EPI to MNI registration
-    ema = epi_mni_align(settings)
+    ema = epi_mni_align()
 
     # Compute TSNR using nipype implementation
-    tsnr = pe.Node(nac.TSNR(), name='compute_tsnr', mem_gb=biggest_file_gb * 2.5)
+    tsnr = pe.Node(nac.TSNR(), name='compute_tsnr', mem_gb=mem_gb * 2.5)
 
     # 7. Compute IQMs
-    iqmswf = compute_iqms(settings)
+    iqmswf = compute_iqms()
     # Reports
-    repwf = individual_reports(settings)
+    repwf = individual_reports()
 
     workflow.connect([
         (inputnode, iqmswf, [('in_file', 'inputnode.in_file')]),
@@ -151,18 +134,20 @@ def fmri_qc_workflow(dataset, settings, name='funcMRIQC'):
         (hmcwf, outputnode, [('outputnode.out_fd', 'out_fd')]),
     ])
 
-    if settings.get('fft_spikes_detector', False):
+    if config.workflow.fft_spikes_detector:
         workflow.connect([
             (iqmswf, repwf, [('outputnode.out_spikes', 'inputnode.in_spikes'),
                              ('outputnode.out_fft', 'inputnode.in_fft')]),
         ])
 
-    if settings.get('ica', False):
+    if config.workflow.ica:
+        from niworkflows.interfaces import segmentation as nws
         melodic = pe.Node(nws.MELODICRPT(no_bet=True,
                                          no_mask=True,
                                          no_mm=True,
+                                         compress_report=False,
                                          generate_report=True),
-                          name="ICA", mem_gb=biggest_file_gb * 5)
+                          name="ICA", mem_gb=max(mem_gb * 5, 8))
         workflow.connect([
             (sanitize, melodic, [('out_file', 'in_files')]),
             (skullstrip_epi, melodic, [('outputnode.out_file', 'report_mask')]),
@@ -170,14 +155,13 @@ def fmri_qc_workflow(dataset, settings, name='funcMRIQC'):
         ])
 
     # Upload metrics
-    if not settings.get('no_sub', False):
+    if not config.execution.no_sub:
         from ..interfaces.webapi import UploadIQMs
         upldwf = pe.Node(UploadIQMs(), name='UploadMetrics')
-        upldwf.inputs.url = settings.get('webapi_url')
-        if settings.get('webapi_port'):
-            upldwf.inputs.port = settings.get('webapi_port')
-        upldwf.inputs.email = settings.get('email')
-        upldwf.inputs.strict = settings.get('upload_strict', False)
+        upldwf.inputs.url = config.execution.webapi_url
+        upldwf.inputs.strict = config.execution.upload_strict
+        if config.execution.webapi_port:
+            upldwf.inputs.port = config.execution.webapi_port
 
         workflow.connect([
             (iqmswf, upldwf, [('outputnode.out_file', 'in_iqms')]),
@@ -186,21 +170,25 @@ def fmri_qc_workflow(dataset, settings, name='funcMRIQC'):
     return workflow
 
 
-def compute_iqms(settings, name='ComputeIQMs'):
+def compute_iqms(name='ComputeIQMs'):
     """
     Workflow that actually computes the IQMs
 
     .. workflow::
 
-      from mriqc.workflows.functional import compute_iqms
-      wf = compute_iqms(settings={'output_dir': 'out'})
+        from mriqc.workflows.functional import compute_iqms
+        from mriqc.testing import mock_config
+        with mock_config():
+            wf = compute_iqms()
 
 
     """
+    from niworkflows.interfaces.bids import ReadSidecarJSON
+
     from .utils import _tofloat
     from ..interfaces.transitional import GCOR
 
-    biggest_file_gb = settings.get("biggest_file_size_gb", 1)
+    mem_gb = config.workflow.biggest_file_gb
 
     workflow = pe.Workflow(name=name)
     inputnode = pe.Node(niu.IdentityInterface(fields=[
@@ -212,25 +200,25 @@ def compute_iqms(settings, name='ComputeIQMs'):
         name='outputnode')
 
     # Set FD threshold
-    inputnode.inputs.fd_thres = settings.get('fd_thres', 0.2)
+    inputnode.inputs.fd_thres = config.workflow.fd_thres
 
     # Compute DVARS
     dvnode = pe.Node(nac.ComputeDVARS(save_plot=False, save_all=True), name='ComputeDVARS',
-                     mem_gb=biggest_file_gb * 3)
+                     mem_gb=mem_gb * 3)
 
     # AFNI quality measures
     fwhm_interface = get_fwhmx()
     fwhm = pe.Node(fwhm_interface, name='smoothness')
     # fwhm.inputs.acf = True  # add when AFNI >= 16
     outliers = pe.Node(afni.OutlierCount(fraction=True, out_file='outliers.out'),
-                       name='outliers', mem_gb=biggest_file_gb * 2.5)
+                       name='outliers', mem_gb=mem_gb * 2.5)
 
     quality = pe.Node(afni.QualityIndex(automask=True), out_file='quality.out',
-                      name='quality', mem_gb=biggest_file_gb * 3)
+                      name='quality', mem_gb=mem_gb * 3)
 
-    gcor = pe.Node(GCOR(), name='gcor', mem_gb=biggest_file_gb * 2)
+    gcor = pe.Node(GCOR(), name='gcor', mem_gb=mem_gb * 2)
 
-    measures = pe.Node(FunctionalQC(), name='measures', mem_gb=biggest_file_gb * 3)
+    measures = pe.Node(FunctionalQC(), name='measures', mem_gb=mem_gb * 3)
 
     workflow.connect([
         (inputnode, dvnode, [('hmc_epi', 'in_file'),
@@ -257,32 +245,29 @@ def compute_iqms(settings, name='ComputeIQMs'):
     # Add metadata
     meta = pe.Node(ReadSidecarJSON(), name='metadata',
                    run_without_submitting=True)
-    addprov = pe.Node(niu.Function(function=_add_provenance), name='provenance',
+    addprov = pe.Node(AddProvenance(modality="bold"),
+                      name='provenance',
                       run_without_submitting=True)
-    addprov.inputs.settings = {
-        'fd_thres': settings.get('fd_thres', 0.2),
-        'hmc_fsl': settings.get('hmc_fsl', True),
-    }
 
     # Save to JSON file
     datasink = pe.Node(IQMFileSink(
-        modality='bold', out_dir=str(settings['output_dir']),
-        dataset=settings.get('dataset_name', 'unknown')),
+        modality='bold', out_dir=str(config.execution.output_dir),
+        dataset=config.execution.dsname),
         name='datasink', run_without_submitting=True)
 
     workflow.connect([
-        (inputnode, datasink, [('exclude_index', 'dummy_trs')]),
+        (inputnode, datasink, [('in_file', 'in_file'),
+                               ('exclude_index', 'dummy_trs')]),
         (inputnode, meta, [('in_file', 'in_file')]),
         (inputnode, addprov, [('in_file', 'in_file')]),
-        (meta, datasink, [('relative_path', 'in_file'),
-                          ('subject_id', 'subject_id'),
-                          ('session_id', 'session_id'),
-                          ('task_id', 'task_id'),
-                          ('acq_id', 'acq_id'),
-                          ('rec_id', 'rec_id'),
-                          ('run_id', 'run_id'),
+        (meta, datasink, [('subject', 'subject_id'),
+                          ('session', 'session_id'),
+                          ('task', 'task_id'),
+                          ('acquisition', 'acq_id'),
+                          ('reconstruction', 'rec_id'),
+                          ('run', 'run_id'),
                           ('out_dict', 'metadata')]),
-        (addprov, datasink, [('out', 'provenance')]),
+        (addprov, datasink, [('out_prov', 'provenance')]),
         (outliers, datasink, [(('out_file', _parse_tout), 'aor')]),
         (gcor, datasink, [(('out', _tofloat), 'gcor')]),
         (quality, datasink, [(('out_file', _parse_tqual), 'aqi')]),
@@ -291,7 +276,7 @@ def compute_iqms(settings, name='ComputeIQMs'):
     ])
 
     # FFT spikes finder
-    if settings.get('fft_spikes_detector', False):
+    if config.workflow.fft_spikes_detector:
         from .utils import slice_wise_fft
         spikes_fft = pe.Node(niu.Function(
             input_names=['in_file'],
@@ -307,21 +292,24 @@ def compute_iqms(settings, name='ComputeIQMs'):
     return workflow
 
 
-def individual_reports(settings, name='ReportsWorkflow'):
+def individual_reports(name='ReportsWorkflow'):
     """
     Encapsulates nodes writing plots
 
     .. workflow::
 
-      from mriqc.workflows.functional import individual_reports
-      wf = individual_reports(settings={'output_dir': 'out'})
+        from mriqc.workflows.functional import individual_reports
+        from mriqc.testing import mock_config
+        with mock_config():
+            wf = individual_reports()
 
     """
+    from niworkflows.interfaces.plotting import FMRISummary
     from ..interfaces import PlotMosaic, PlotSpikes
-    from ..reports import individual_html
+    from ..interfaces.reports import IndividualReport
 
-    verbose = settings.get('verbose_reports', False)
-    biggest_file_gb = settings.get("biggest_file_size_gb", 1)
+    verbose = config.execution.verbose_reports
+    mem_gb = config.workflow.biggest_file_gb
 
     pages = 5
     extra_pages = int(verbose) * 4
@@ -334,16 +322,16 @@ def individual_reports(settings, name='ReportsWorkflow'):
         name='inputnode')
 
     # Set FD threshold
-    inputnode.inputs.fd_thres = settings.get('fd_thres', 0.2)
+    inputnode.inputs.fd_thres = config.workflow.fd_thres
 
     spmask = pe.Node(niu.Function(
         input_names=['in_file', 'in_mask'], output_names=['out_file', 'out_plot'],
-        function=spikes_mask), name='SpikesMask', mem_gb=biggest_file_gb * 3.5)
+        function=spikes_mask), name='SpikesMask', mem_gb=mem_gb * 3.5)
 
     spikes_bg = pe.Node(Spikes(no_zscore=True, detrend=False), name='SpikesFinderBgMask',
-                        mem_gb=biggest_file_gb * 2.5)
+                        mem_gb=mem_gb * 2.5)
 
-    bigplot = pe.Node(FMRISummary(), name='BigPlot', mem_gb=biggest_file_gb * 3.5)
+    bigplot = pe.Node(FMRISummary(), name='BigPlot', mem_gb=mem_gb * 3.5)
     workflow.connect([
         (inputnode, spikes_bg, [('in_ras', 'in_file')]),
         (inputnode, spmask, [('in_ras', 'in_file')]),
@@ -368,15 +356,14 @@ def individual_reports(settings, name='ReportsWorkflow'):
         cmap='viridis'), name='PlotMosaicSD')
 
     mplots = pe.Node(niu.Merge(pages + extra_pages + int(
-        settings.get('fft_spikes_detector', False)) + int(
-        settings.get('ica', False))), name='MergePlots')
-    rnode = pe.Node(niu.Function(
-        input_names=['in_iqms', 'in_plots'], output_names=['out_file'],
-        function=individual_html), name='GenerateReport')
+        config.workflow.fft_spikes_detector) + int(
+        config.workflow.ica)), name='MergePlots')
+    rnode = pe.Node(IndividualReport(), name='GenerateReport')
 
     # Link images that should be reported
     dsplots = pe.Node(nio.DataSink(
-        base_directory=str(settings['output_dir']), parameterization=False),
+        base_directory=str(config.execution.output_dir),
+        parameterization=False),
         name='dsplots', run_without_submitting=True)
 
     workflow.connect([
@@ -390,7 +377,7 @@ def individual_reports(settings, name='ReportsWorkflow'):
         (rnode, dsplots, [('out_file', '@html_report')]),
     ])
 
-    if settings.get('fft_spikes_detector', False):
+    if config.workflow.fft_spikes_detector:
         mosaic_spikes = pe.Node(PlotSpikes(
             out_file='plot_spikes.svg', cmap='viridis',
             title='High-Frequency spikes'),
@@ -403,10 +390,8 @@ def individual_reports(settings, name='ReportsWorkflow'):
             (mosaic_spikes, mplots, [('out_file', 'in4')])
         ])
 
-    if settings.get('ica', False):
-        page_number = 4
-        if settings.get('fft_spikes_detector', False):
-            page_number += 1
+    if config.workflow.ica:
+        page_number = 4 + config.workflow.fft_spikes_detector
         workflow.connect([
             (inputnode, mplots, [('ica_report', 'in%d' % page_number)])
         ])
@@ -450,8 +435,10 @@ def fmri_bmsk_workflow(name='fMRIBrainMask', use_bet=False):
 
     .. workflow::
 
-      from mriqc.workflows.functional import fmri_bmsk_workflow
-      wf = fmri_bmsk_workflow()
+        from mriqc.workflows.functional import fmri_bmsk_workflow
+        from mriqc.testing import mock_config
+        with mock_config():
+            wf = fmri_bmsk_workflow()
 
 
     """
@@ -486,17 +473,20 @@ def fmri_bmsk_workflow(name='fMRIBrainMask', use_bet=False):
     return workflow
 
 
-def hmc_mcflirt(settings, name='fMRI_HMC_mcflirt'):
+def hmc_mcflirt(name='fMRI_HMC_mcflirt'):
     """
     An :abbr:`HMC (head motion correction)` for functional scans
     using FSL MCFLIRT
 
     .. workflow::
 
-      from mriqc.workflows.functional import hmc_mcflirt
-      wf = hmc_mcflirt({'biggest_file_size_gb': 1})
+        from mriqc.workflows.functional import hmc_mcflirt
+        from mriqc.testing import mock_config
+        with mock_config():
+            wf = hmc_mcflirt()
 
     """
+    from niworkflows.interfaces.registration import EstimateReferenceImage
 
     workflow = pe.Workflow(name=name)
 
@@ -506,11 +496,11 @@ def hmc_mcflirt(settings, name='fMRI_HMC_mcflirt'):
     outputnode = pe.Node(niu.IdentityInterface(
         fields=['out_file', 'out_fd']), name='outputnode')
 
-    gen_ref = pe.Node(nwr.EstimateReferenceImage(mc_method="AFNI"), name="gen_ref")
+    gen_ref = pe.Node(EstimateReferenceImage(mc_method="AFNI"), name="gen_ref")
 
     mcflirt = pe.Node(fsl.MCFLIRT(save_plots=True, interpolation='sinc'),
                       name='MCFLIRT',
-                      mem_gb=settings['biggest_file_size_gb'] * 2.5)
+                      mem_gb=config.workflow.biggest_file_gb * 2.5)
 
     fdnode = pe.Node(nac.FramewiseDisplacement(normalize=False,
                                                parameter_source="FSL"),
@@ -529,20 +519,22 @@ def hmc_mcflirt(settings, name='fMRI_HMC_mcflirt'):
     return workflow
 
 
-def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
-             deoblique=False, start_idx=None, stop_idx=None):
+def hmc_afni(name='fMRI_HMC_afni'):
     """
     A :abbr:`HMC (head motion correction)` workflow for
     functional scans
 
     .. workflow::
 
-      from mriqc.workflows.functional import hmc_afni
-      wf = hmc_afni({'biggest_file_size_gb': 1})
+        from mriqc.workflows.functional import hmc_afni
+        from mriqc.testing import mock_config
+        with mock_config():
+            wf = hmc_afni()
 
     """
+    from niworkflows.interfaces.registration import EstimateReferenceImage
 
-    biggest_file_gb = settings.get("biggest_file_size_gb", 1)
+    mem_gb = config.workflow.biggest_file_gb
 
     workflow = pe.Workflow(name=name)
 
@@ -552,7 +544,10 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
     outputnode = pe.Node(niu.IdentityInterface(
         fields=['out_file', 'out_fd']), name='outputnode')
 
-    if (start_idx is not None) or (stop_idx is not None):
+    if any((
+        config.workflow.start_idx is not None,
+        config.workflow.stop_idx is not None
+    )):
         drop_trs = pe.Node(afni.Calc(expr='a', outputtype='NIFTI_GZ'),
                            name='drop_trs')
         workflow.connect([
@@ -567,12 +562,12 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
             (inputnode, drop_trs, [('in_file', 'out_file')]),
         ])
 
-    gen_ref = pe.Node(nwr.EstimateReferenceImage(mc_method="AFNI"), name="gen_ref")
+    gen_ref = pe.Node(EstimateReferenceImage(mc_method="AFNI"), name="gen_ref")
 
     # calculate hmc parameters
     hmc = pe.Node(
         afni.Volreg(args='-Fourier -twopass', zpad=4, outputtype='NIFTI_GZ'),
-        name='motion_correct', mem_gb=biggest_file_gb * 2.5)
+        name='motion_correct', mem_gb=mem_gb * 2.5)
 
     # Compute the frame-wise displacement
     fdnode = pe.Node(nac.FramewiseDisplacement(normalize=False,
@@ -595,7 +590,11 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
 
     despike_node = pe.Node(afni.Despike(outputtype='NIFTI_GZ'), name='despike')
 
-    if st_correct and despike and deoblique:
+    if all((
+        config.workflow.correct_slice_timing,
+        config.workflow.despike,
+        config.workflow.deoblique
+    )):
 
         workflow.connect([
             (drop_trs, st_corr, [('out_file', 'in_file')]),
@@ -604,8 +603,7 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
             (deoblique_node, gen_ref, [('out_file', 'in_file')]),
             (deoblique_node, hmc, [('out_file', 'in_file')]),
         ])
-
-    elif st_correct and despike:
+    elif config.workflow.correct_slice_timing and config.workflow.despike:
 
         workflow.connect([
             (drop_trs, st_corr, [('out_file', 'in_file')]),
@@ -614,7 +612,7 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
             (despike_node, hmc, [('out_file', 'in_file')]),
         ])
 
-    elif st_correct and deoblique:
+    elif config.workflow.correct_slice_timing and config.workflow.deoblique:
 
         workflow.connect([
             (drop_trs, st_corr, [('out_file', 'in_file')]),
@@ -623,7 +621,7 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
             (deoblique_node, hmc, [('out_file', 'in_file')]),
         ])
 
-    elif st_correct:
+    elif config.workflow.correct_slice_timing:
 
         workflow.connect([
             (drop_trs, st_corr, [('out_file', 'in_file')]),
@@ -631,7 +629,7 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
             (st_corr, hmc, [('out_file', 'in_file')]),
         ])
 
-    elif despike and deoblique:
+    elif config.workflow.despike and config.workflow.deoblique:
 
         workflow.connect([
             (drop_trs, despike_node, [('out_file', 'in_file')]),
@@ -640,7 +638,7 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
             (deoblique_node, hmc, [('out_file', 'in_file')]),
         ])
 
-    elif despike:
+    elif config.workflow.despike:
 
         workflow.connect([
             (drop_trs, despike_node, [('out_file', 'in_file')]),
@@ -648,7 +646,7 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
             (despike_node, hmc, [('out_file', 'in_file')]),
         ])
 
-    elif deoblique:
+    elif config.workflow.deoblique:
 
         workflow.connect([
             (drop_trs, deoblique_node, [('out_file', 'in_file')]),
@@ -665,7 +663,7 @@ def hmc_afni(settings, name='fMRI_HMC_afni', st_correct=False, despike=False,
     return workflow
 
 
-def epi_mni_align(settings, name='SpatialNormalization'):
+def epi_mni_align(name='SpatialNormalization'):
     """
     Uses FSL FLIRT with the BBR cost function to find the transform that
     maps the EPI space into the MNI152-nonlinear-symmetric atlas.
@@ -677,23 +675,21 @@ def epi_mni_align(settings, name='SpatialNormalization'):
 
     .. workflow::
 
-      from mriqc.workflows.functional import epi_mni_align
-      wf = epi_mni_align({})
+        from mriqc.workflows.functional import epi_mni_align
+        from mriqc.testing import mock_config
+        with mock_config():
+            wf = epi_mni_align()
 
     """
-    from niworkflows.data import get_mni_icbm152_nlin_asym_09c as get_template
+    from templateflow.api import get as get_template
     from niworkflows.interfaces.registration import (
         RobustMNINormalizationRPT as RobustMNINormalization
     )
-    from pkg_resources import resource_filename as pkgrf
 
     # Get settings
-    testing = settings.get('testing', False)
-    n_procs = settings.get('n_procs', 1)
-    ants_nthreads = settings.get('ants_nthreads', DEFAULTS['ants_nthreads'])
-
-    # Init template
-    mni_template = get_template()
+    testing = config.execution.debug
+    n_procs = config.nipype.nprocs
+    ants_nthreads = config.nipype.omp_nthreads
 
     workflow = pe.Workflow(name=name)
     inputnode = pe.Node(niu.IdentityInterface(fields=['epi_mean', 'epi_mask']),
@@ -701,35 +697,38 @@ def epi_mni_align(settings, name='SpatialNormalization'):
     outputnode = pe.Node(niu.IdentityInterface(
         fields=['epi_mni', 'epi_parc', 'report']), name='outputnode')
 
-    epimask = pe.Node(fsl.ApplyMask(), name='EPIApplyMask')
-
-    n4itk = pe.Node(ants.N4BiasFieldCorrection(dimension=3), name='SharpenEPI')
+    n4itk = pe.Node(ants.N4BiasFieldCorrection(dimension=3, copy_header=True),
+                    name='SharpenEPI')
 
     norm = pe.Node(RobustMNINormalization(
-        num_threads=ants_nthreads,
-        float=settings.get('ants_float', False),
-        template='mni_icbm152_nlin_asym_09c',
-        reference_image=pkgrf('mriqc', 'data/mni/2mm_T2_brain.nii.gz'),
+        explicit_masking=False,
         flavor='testing' if testing else 'precise',
-        moving='EPI',
-        generate_report=True,),
-        name='EPI2MNI',
-        num_threads=n_procs,
-        mem_gb=3)
+        float=config.execution.ants_float,
+        generate_report=True,
+        moving='boldref',
+        num_threads=ants_nthreads,
+        reference='boldref',
+        reference_image=str(get_template(
+            'MNI152NLin2009cAsym', resolution=2, suffix='boldref')),
+        reference_mask=str(get_template(
+            'MNI152NLin2009cAsym', resolution=2, desc='brain', suffix='mask')),
+        template='MNI152NLin2009cAsym',
+        template_resolution=2, ),
+        name='EPI2MNI', num_threads=n_procs, mem_gb=3)
 
     # Warp segmentation into EPI space
     invt = pe.Node(ants.ApplyTransforms(
         float=True,
-        input_image=op.join(mni_template, '1mm_parc.nii.gz'),
-        dimension=3, default_value=0, interpolation='NearestNeighbor'),
+        input_image=str(get_template('MNI152NLin2009cAsym', resolution=1,
+                                     desc='carpet', suffix='dseg')),
+        dimension=3, default_value=0, interpolation='MultiLabel'),
         name='ResampleSegmentation')
 
     workflow.connect([
         (inputnode, invt, [('epi_mean', 'reference_image')]),
         (inputnode, n4itk, [('epi_mean', 'input_image')]),
-        (inputnode, epimask, [('epi_mask', 'mask_file')]),
-        (n4itk, epimask, [('output_image', 'in_file')]),
-        (epimask, norm, [('out_file', 'moving_image')]),
+        (inputnode, norm, [('epi_mask', 'moving_mask')]),
+        (n4itk, norm, [('output_image', 'moving_image')]),
         (norm, invt, [
             ('inverse_composite_transform', 'transforms')]),
         (invt, outputnode, [('output_image', 'epi_parc')]),
@@ -792,31 +791,14 @@ def spikes_mask(in_file, in_mask=None, out_file=None):
         new_mask_3d[:, 0:2, :] = True
         new_mask_3d[:, -3:-1, :] = True
 
-    mask_nii = nb.Nifti1Image(new_mask_3d.astype(np.uint8), in_4d_nii.get_affine(),
-                              in_4d_nii.get_header())
+    mask_nii = nb.Nifti1Image(new_mask_3d.astype(np.uint8), in_4d_nii.affine,
+                              in_4d_nii.header)
     mask_nii.to_filename(out_file)
 
     plot_roi(mask_nii, mean_img(in_4d_nii), output_file=out_plot)
     return out_file, out_plot
 
 
-def _add_provenance(in_file, settings):
-    from mriqc import __version__ as version
-    from nipype.utils.filemanip import hash_infile
-    out_prov = {
-        'md5sum': hash_infile(in_file),
-        'version': version,
-        'software': 'mriqc',
-        'webapi_url': settings.get('webapi_url'),
-        'webapi_port': settings.get('webapi_port'),
-    }
-
-    if settings:
-        out_prov['settings'] = settings
-
-    return out_prov
-
-
 def _mean(inlist):
     import numpy as np
     return np.mean(inlist)
